==> alsangue-0.1.tar.gz: alsangue-0.1/README.md <==
# alsangue

[![Python 3.x Support](https://img.shields.io/pypi/pyversions/Django.svg)](https://python.org)
[![License: GPL v3+](https://img.shields.io/badge/license-GPL%20v3%2B-blue.svg)](http://www.gnu.org/licenses/gpl-3.0) 


*alsangue* is a naive static website builder written in `python`.

## Installation

*alsangue* is available through the [Python Package Index (PyPI)](https://pypi.org/). Pip is pre-installed if `python >= 3.4` has been downloaded from [python.org](https://python.org); if you're using a GNU/Linux distribution, you can find how to install it on this [page](https://packaging.python.org/guides/installing-using-linux-tools/#installing-pip-setuptools-wheel-with-linux-package-managers).

After setting up pip, you can install *alsangue* by simply typing in your terminal

    # pip3 install alsangue

## Usage

*alsangue* install a command line utility with the same name, `pgpgram`. You can invoke command line help with `pgpgram --help` and get command options with

    pgpgram <command> --help

You can find an example `content` directory in this repo which you can edit to build your own website.

## About

This program is licensed under [GNU General Public License v3 or later](https://www.gnu.org/licenses/gpl-3.0.en.html) by [Pellegrino Prevete](http://prevete.ml). If you find this program useful, consider offering me a [beer](https://patreon.com/tallero), a new [computer](https://patreon.com/tallero) or a part time remote [job](mailto:pellegrinoprevete@gmail.com) to help me pay the bills.

==> alsangue-0.1.1.tar.gz: alsangue-0.1.1/README.md <==
# alsangue

[![Python 3.x Support](https://img.shields.io/pypi/pyversions/Django.svg)](https://python.org)
[![License: GPL v3+](https://img.shields.io/badge/license-GPL%20v3%2B-blue.svg)](http://www.gnu.org/licenses/gpl-3.0) 


*alsangue* is a naive static website builder written in `python`.

## Installation

*alsangue* is available through the [Python Package Index (PyPI)](https://pypi.org/). Pip is pre-installed if `python >= 3.4` has been downloaded from [python.org](https://python.org); if you're using a GNU/Linux distribution, you can find how to install it on this [page](https://packaging.python.org/guides/installing-using-linux-tools/#installing-pip-setuptools-wheel-with-linux-package-managers).

After setting up pip, you can install *alsangue* by simply typing in your terminal

    # pip3 install alsangue

## Usage

*alsangue* install a command line utility with the same name, `alsangue`. You can invoke command line help with `alsangue --help` and get command options with

    alsangue <command> --help

You can find an example `content` directory in this repo which you can edit to build your own website.

## About

This program is licensed under [GNU General Public License v3 or later](https://www.gnu.org/licenses/gpl-3.0.en.html) by [Pellegrino Prevete](http://prevete.ml). If you find this program useful, consider offering me a [beer](https://patreon.com/tallero), a new [computer](https://patreon.com/tallero) or a part time remote [job](mailto:pellegrinoprevete@gmail.com) to help me pay the bills.
